summaryrefslogtreecommitdiff
path: root/lisp/bookmark.el
diff options
context:
space:
mode:
authorGlenn Morris <rgm@gnu.org>2020-07-20 07:50:44 -0700
committerGlenn Morris <rgm@gnu.org>2020-07-20 07:50:44 -0700
commitfe2d0ede2874a5411d14e1cad3d72883823719c1 (patch)
treeadb1bd4bcd6d80870bb0d1753d292b4db3773e1d /lisp/bookmark.el
parent0cbafc236bde83ff1600c1e51408e5d0dd3d1a92 (diff)
parentcd93debc600b31ec7d257ba0195ae7132df83816 (diff)
downloademacs-fe2d0ede2874a5411d14e1cad3d72883823719c1.tar.gz
Merge from origin/emacs-27
cd93debc60 (origin/emacs-27) Merge branch 'emacs-27' of git.savannah.... 2c0c613ec5 Document prefix arg effects for 'epa-mail-{sign,encrypt}' 551123e0b2 * etc/NEWS: Correct description of :client-certificate change 05c4329cf5 Revert "Fix filename completion in shell mode buffers" de68572742 Improve documentation of 'bookmark-bmenu-mode' fd85e70be7 Update systems using GnuTLS certificate files 0d4ba1c2b2 Improve documentation of 'kill-emacs' b3bbd4fd00 Improve documentation of 'display-raw-bytes-as-hex' f50d79af6b Correct descriptions of init file e325d2638c Fix interrupt-process on MS-Windows d24e56a5e4 Revert "* doc/misc/flymake.texi (An annotated example back... # Conflicts: # etc/NEWS
Diffstat (limited to 'lisp/bookmark.el')
-rw-r--r--lisp/bookmark.el3
1 files changed, 2 insertions, 1 deletions
diff --git a/lisp/bookmark.el b/lisp/bookmark.el
index 5bb16981711..de7d60f97eb 100644
--- a/lisp/bookmark.el
+++ b/lisp/bookmark.el
@@ -1774,7 +1774,8 @@ Bookmark names preceded by a \"*\" have annotations.
\\[bookmark-bmenu-show-annotation] -- show the annotation, if it exists, for the current bookmark
in another buffer.
\\[bookmark-bmenu-show-all-annotations] -- show the annotations of all bookmarks in another buffer.
-\\[bookmark-bmenu-edit-annotation] -- edit the annotation for the current bookmark."
+\\[bookmark-bmenu-edit-annotation] -- edit the annotation for the current bookmark.
+\\[bookmark-bmenu-search] -- incrementally search for bookmarks."
(setq truncate-lines t)
(setq buffer-read-only t))